@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -40,7 +40,7 @@
 
 /* private interface data
  */
-struct NAIFactoryProviderInterfacePrivate {
+struct _NAIFactoryProviderInterfacePrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
@@ -59,7 +59,11 @@ static guint v_factory_provider_write_start( const NAIFactoryProvider *writer, v
 static guint v_factory_provider_write_done( const NAIFactoryProvider *writer, void *writer_data, NAIFactoryObject *serializable, GSList **messages );
 
 /**
+ * na_ifactory_provider_get_type:
+ *
  * Registers the GType of this interface.
+ *
+ * Returns: the #NAIFactoryProvider #GType.
  */
 GType
 na_ifactory_provider_get_type( void )
@@ -147,12 +151,40 @@ ifactory_provider_get_version( const NAIFactoryProvider *instance )
 /**
  * na_ifactory_provider_read_item:
  * @reader: the instance which implements this #NAIFactoryProvider interface.
- * @reader_data: instance data.
+ * @reader_data: instance data which will be provided back to the interface
+ *  methods
  * @object: the #NAIFactoryObject object to be unserialilzed.
  * @messages: a pointer to a #GSList list of strings; the implementation
  *  may append messages to this list, but shouldn't reinitialize it.
  *
- * Returns: a newly instantiated #NAIFactoryObject object just readen from @reader.
+ * This function is to be called by a #NAIIOProvider which would wish read
+ * its items. The function takes care of collecting and structuring data,
+ * while the callback interface methods #NAIFactoryProviderInterface.read_start(),
+ * #NAIFactoryProviderInterface.read_data() and #NAIFactoryProviderInterface.read_done()
+ * just have to fill a given #NADataBoxed with the ad-hoc data type.
+ *
+ * <example>
+ *   <programlisting>
+ *     &lcomment;
+ *      * allocate the object to be readen
+ *      &rcomment;
+ *     NAObjectItem *item = NA_OBJECT_ITEM( na_object_action_new());
+ *     &lcomment;
+ *      * some data we may need to have access to in callback methods
+ *      &rcomment;
+ *     void *data;
+ *     &lcomment;
+ *      * now call interface function
+ *      &rcomment;
+ *     na_ifactory_provider_read_item(
+ *         NA_IFACTORY_PROVIDER( provider ),
+ *         data,
+ *         NA_IFACTORY_OBJECT( item ),
+ *         messages );
+ *   </programlisting>
+ * </example>
+ *
+ * Since: 2.30
  */
 void
 na_ifactory_provider_read_item( const NAIFactoryProvider *reader, void *reader_data, NAIFactoryObject *object, GSList **messages )
@@ -172,13 +204,16 @@ na_ifactory_provider_read_item( const NAIFactoryProvider *reader, void *reader_d
  * na_ifactory_provider_write_item:
  * @writer: the instance which implements this #NAIFactoryProvider interface.
  * @writer_data: instance data.
- * @serializable: the #NAIFactoryObject-derived object to be serialized.
+ * @object: the #NAIFactoryObject derived object to be serialized.
  * @messages: a pointer to a #GSList list of strings; the implementation
  *  may append messages to this list, but shouldn't reinitialize it.
  *
- * Writes the data down to the FactoryProvider.
+ * This function is to be called by a #NAIIOProvider which would wish write
+ * an item. The function takes care of collecting and writing elementary data.
  *
  * Returns: a NAIIOProvider operation return code.
+ *
+ * Since: 2.30
  */
 guint
 na_ifactory_provider_write_item( const NAIFactoryProvider *writer, void *writer_data, NAIFactoryObject *object, GSList **messages )
