@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -39,13 +39,13 @@
 
 /* private class data
  */
-struct NAObjectIdClassPrivate {
+struct _NAObjectIdClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NAObjectIdPrivate {
+struct _NAObjectIdPrivate {
 	gboolean   dispose_has_run;
 };
 
@@ -223,9 +223,20 @@ object_is_valid( const NAObject *object )
  * Sort the objects in alphabetical ascending order of their label.
  *
  * Returns:
- * -1 if @a must be sorted before @b,
- *  0 if @a and @b are equal from the local point of view,
- *  1 if @a must be sorted after @b.
+ *
+ * <itemizedlist>
+ *   <listitem>
+ *     <para>-1 if @a must be sorted before @b,</para>
+ *   </listitem>
+ *   <listitem>
+ *     <para>0 if @a and @b are equal from the local point of view,</para>
+ *   </listitem>
+ *   <listitem>
+ *     <para>1 if @a must be sorted after @b.</para>
+ *   </listitem>
+ * </itemizedlist>
+ *
+ * Since: 2.30
  */
 gint
 na_object_id_sort_alpha_asc( const NAObjectId *a, const NAObjectId *b )
@@ -252,9 +263,20 @@ na_object_id_sort_alpha_asc( const NAObjectId *a, const NAObjectId *b )
  * Sort the objects in alphabetical descending order of their label.
  *
  * Returns:
- * -1 if @a must be sorted before @b,
- *  0 if @a and @b are equal from the local point of view,
- *  1 if @a must be sorted after @b.
+ *
+ * <itemizedlist>
+ *   <listitem>
+ *     <para>-1 if @a must be sorted before @b,</para>
+ *   </listitem>
+ *   <listitem>
+ *     <para>0 if @a and @b are equal from the local point of view,</para>
+ *   </listitem>
+ *   <listitem>
+ *     <para>1 if @a must be sorted after @b.</para>
+ *   </listitem>
+ * </itemizedlist>
+ *
+ * Since: 2.30
  */
 gint
 na_object_id_sort_alpha_desc( const NAObjectId *a, const NAObjectId *b )
@@ -266,7 +288,7 @@ na_object_id_sort_alpha_desc( const NAObjectId *a, const NAObjectId *b )
  * na_object_id_prepare_for_paste:
  * @object: the #NAObjectId object to be pasted.
  * @relabel: whether this object should be relabeled when pasted.
- * @relabel: whether this item should be renumbered ?
+ * @renumber: whether this item should be renumbered ?
  * @parent: the parent of @object, or %NULL.
  *
  * Prepares @object to be pasted.
@@ -280,6 +302,8 @@ na_object_id_sort_alpha_desc( const NAObjectId *a, const NAObjectId *b )
  *
  * Actual relabeling takes place if @relabel is %TRUE, depending of the
  * user preferences.
+ *
+ * Since: 2.30
  */
 void
 na_object_id_prepare_for_paste( NAObjectId *object, gboolean relabel, gboolean renumber, NAObjectId *parent )
@@ -309,6 +333,7 @@ na_object_id_prepare_for_paste( NAObjectId *object, gboolean relabel, gboolean r
 					na_object_set_copy_of_label( object );
 				}
 				na_object_set_provider( object, NULL );
+				na_object_set_provider_data( object, NULL );
 				na_object_set_readonly( object, FALSE );
 			}
 			if( NA_IS_OBJECT_MENU( object )){
@@ -326,6 +351,8 @@ na_object_id_prepare_for_paste( NAObjectId *object, gboolean relabel, gboolean r
  * @object: the #NAObjectId object whose label is to be changed.
  *
  * Sets the 'Copy of' label.
+ *
+ * Since: 2.30
  */
 void
 na_object_id_set_copy_of_label( NAObjectId *object )
@@ -353,11 +380,13 @@ na_object_id_set_copy_of_label( NAObjectId *object )
  * @object: the #NAObjectId object whose internal identifiant is to be
  * set.
  * @new_parent: if @object is a #NAObjectProfile, then @new_parent
- * should be set to the #NAObjectActio new parent. Else, it would not
+ * should be set to the #NAObjectAction new parent. Else, it would not
  * be possible to allocate a new profile id compatible with already
  * existing ones.
  *
  * Request a new id to the derived class, and set it.
+ *
+ * Since: 2.30
  */
 void
 na_object_id_set_new_id( NAObjectId *object, const NAObjectId *new_parent )
