@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -543,10 +543,17 @@ static void
 try_for_send_ok( NactAddCapabilityDialog *dialog )
 {
 	GtkWidget *button;
+	gboolean is_sensitive;
 
 	button = base_window_get_widget( BASE_WINDOW( dialog ), "OKButton" );
 
-	if( gtk_widget_get_sensitive( button )){
+#if(( GTK_MAJOR_VERSION > 2 ) || ( GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 18 ))
+	is_sensitive = gtk_widget_is_sensitive( button );
+#else
+	is_sensitive = GTK_WIDGET_IS_SENSITIVE( button );
+#endif
+
+	if( is_sensitive ){
 		send_ok( dialog );
 	}
 }
