@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -199,7 +199,7 @@ static const GtkActionEntry entries[] = {
 				N_( "Dump the content of the clipboard object" ),
 				G_CALLBACK( nact_main_menubar_maintainer_on_dump_clipboard ) },
 
-		{ "HelpItem" , GTK_STOCK_HELP, NULL, NULL,
+		{ "HelpItem" , GTK_STOCK_HELP, N_( "Contents" ), "F1",
 				/* i18n: tooltip displayed in the status bar when selecting the Help item */
 				N_( "Display help about this program" ),
 				G_CALLBACK( nact_main_menubar_help_on_help ) },
