@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -297,7 +297,7 @@ static gchar *
 iabout_get_application_name( NAIAbout *instance )
 {
 	/* i18n: title of the About dialog box, when seen from Nautilus file manager */
-	return( g_strdup( _( "Nautilus Actions" )));
+	return( g_strdup( _( "Nautilus-Actions" )));
 }
 
 static void
@@ -972,9 +972,9 @@ create_root_menu( NautilusActions *plugin, GList *menu )
 	icon = na_iabout_get_icon_name();
 	root_item = nautilus_menu_item_new( "NautilusActionsExtensions",
 				/* i18n: label of an automagic root submenu */
-				_( "Nautilus Actions" ),
+				_( "Nautilus-Actions actions" ),
 				/* i18n: tooltip of an automagic root submenu */
-				_( "A submenu which embeds the currently available Nautilus Actions extensions" ),
+				_( "A submenu which embeds the currently available Nautilus-Actions actions and menus" ),
 				icon );
 	attach_submenu_to_item( root_item, menu );
 	nautilus_menu = g_list_append( NULL, root_item );
@@ -1021,8 +1021,8 @@ add_about_item( NautilusActions *plugin, GList *menu )
 		icon = na_iabout_get_icon_name();
 
 		about_item = nautilus_menu_item_new( "AboutNautilusActions",
-					_( "About Nautilus Actions" ),
-					_( "Display information about Nautilus Actions" ),
+					_( "About Nautilus-Actions" ),
+					_( "Display some informations about Nautilus-Actions" ),
 					icon );
 
 		g_signal_connect_data( about_item,
